Test coverage report: ftp_deploy.server.forms.login

# ftp_deploy.server.forms.login: 14 total statements, 100.0% covered

Generated: Thu 2013-12-19 21:13 GMT

Source file: /var/www/service.dev/service/ftp_deploy/server/forms/login.py

Stats: 9 executed, 0 missed, 5 excluded, 9 ignored

1. `from django import forms`
2. `from django.contrib.auth.models import User`
3. ``
4. `from crispy_forms.helper import FormHelper`
5. `from crispy_forms.bootstrap import FormActions`
6. `from crispy_forms.layout import Layout, Field, Submit, Div, HTML`
7. ``
8. ``
9. `class LoginForm(forms.Form):`
10. `username = forms.CharField(widget=forms.TextInput(attrs={'placeholder': 'Username', 'required': 'required'}))`
11. `password = forms.CharField(widget=forms.PasswordInput(render_value=False, attrs={'placeholder': 'Password', 'required': 'required'}))`
12. ``
13. `def __init__(self, *args, **kwargs):`
14. `super(LoginForm, self).__init__(*args, **kwargs)`
15. `self.helper = FormHelper()`
16. `self.helper.form_class = 'form-signin'`
17. `self.helper.form_tag = False`
18. ``
19. `self.helper.layout = Layout(`
20. `'username',`
21. `'password',`
22. `Submit('login', 'Log in', css_class='btn-lg btn-block'),`
23. `)`